@@ -2,8 +2,9 @@
 
 """Number tests."""
 
-import humanize
 import pytest
+
+import humanize
 from humanize import number
 
 
@@ -153,3 +154,20 @@ def test_fractional(test_input, expected):
 )
 def test_scientific(test_args, expected):
     assert humanize.scientific(*test_args) == expected
+
+
+@pytest.mark.parametrize(
+    "test_args, expected",
+    [
+        ([1], "1"),
+        ([None], None),
+        ([0.0001, "{:.0%}"], "0%"),
+        ([0.0001, "{:.0%}", 0.01], "<1%"),
+        ([0.9999, "{:.0%}", None, 0.99], ">99%"),
+        ([0.0001, "{:.0%}", 0.01, None, "under ", None], "under 1%"),
+        ([0.9999, "{:.0%}", None, 0.99, None, "above "], "above 99%"),
+        ([1, humanize.intword, 1e6, None, "under "], "under 1.0 million"),
+    ],
+)
+def test_clamp(test_args, expected):
+    assert humanize.clamp(*test_args) == expected
